@@ -1,6 +1,6 @@
 from libifstate.util import logger, ipr, IfStateLogging
 from libifstate.exception import netlinkerror_classes
-from libifstate.bpf import libbpf, struct_bpf_prog_info
+from libifstate.bpf import libbpf, struct_bpf_prog_info, bpfs_ifstate_dir
 
 from pyroute2.netlink.rtnl.ifinfmsg import XDP_FLAGS_SKB_MODE
 from pyroute2.netlink.rtnl.ifinfmsg import XDP_FLAGS_DRV_MODE
@@ -8,13 +8,14 @@ from pyroute2.netlink.rtnl.ifinfmsg import XDP_FLAGS_HW_MODE
 
 import ctypes
 import os
+import shutil
 
 class XDP():
     def __init__(self, iface, xdp):
         self.iface = iface
         self.xdp = xdp
 
-    def apply(self, do_apply):
+    def apply(self, do_apply, bpf_progs):
         self.link = next(iter(ipr.get_links(ifname=self.iface)), None)
 
         if self.link == None:
@@ -24,10 +25,19 @@ class XDP():
         # get ifindex
         self.idx = self.link['index']
 
+        # new BPF instance (from pinned, bpf or xdp settings)
+        new_prog_tag = None
+        new_prog_fd = None
+
         # get current BPF tag, if any
         current_prog_tag = None
-        current_prog_id = self.link.get_attr('IFLA_XDP', {}).get('IFLA_XDP_PROG_ID')
-        current_attached = self.link.get_attr('IFLA_XDP', {}).get('IFLA_XDP_ATTACHED')
+        current_prog_id = None
+        current_attached = None
+        ifla_xdp = self.link.get_attr('IFLA_XDP')
+        if ifla_xdp is not None:
+            current_prog_id = ifla_xdp.get_attr('IFLA_XDP_PROG_ID')
+            current_attached = ifla_xdp.get_attr('IFLA_XDP_ATTACHED')
+
         if current_prog_id:
             current_prog_fd = libbpf.bpf_prog_get_fd_by_id(current_prog_id)
             if current_prog_fd < 0:
@@ -50,59 +60,30 @@ class XDP():
             'iface': self.iface})
 
         # load new BPF prog
-        new_prog_tag = None
-        new_prog_fd = None
+        new_obj = None
         if not self.xdp:
             new_prog_fd = -1
         elif 'pinned' in self.xdp:
-            fh = open(self.xdp["pinned"], 'r')
-            new_prog_fd = fh.fileno()
-        elif 'object' in self.xdp:
-            obj = libbpf.bpf_object__open_file(
-                os.fsencode(self.xdp["object"]),
-                None,
-            )
-            if not obj:
-                logger.warning('XDP open on {} failed: {}'.format(
-                    self.iface, os.strerror(-current_prog_fd)))
-                return
+            new_prog_fd = libbpf.bpf_obj_get( os.fsencode(self.xdp["pinned"]) )
 
-            logger.debug('loaded object: {}'.format(libbpf.bpf_object__name(obj).decode('ascii')), extra={
-                        'iface': self.iface})
+            if new_prog_fd < 0:
+                logger.warning("pinned BPF object '{}' cannot be opened: {}".format(
+                    self.xdp["pinned"], os.strerror(-new_prog_fd)))
+        elif 'bpf' in self.xdp:
+            if bpf_progs is not None:
+                (new_prog_fd, new_prog_tag) = bpf_progs.get_bpf(self.xdp["bpf"])
 
-            rc = libbpf.bpf_object__load(obj)
-            if rc < 0:
-                logger.warning('XDP load on {} failed: {}'.format(
-                    self.iface, os.strerror(-rc)))
-                return
-
-            prog = libbpf.bpf_object__next_program(obj, None)
-            while prog:
-                section = libbpf.bpf_program__section_name(prog).decode('ascii')
-
-                logger.debug('  section: {}'.format(section), extra={
+            if new_prog_fd == -1:
+                logger.warning("BPF program '{}' not loaded for {}".format(
+                    self.xdp["bpf"], self.iface))
+            else:
+                logger.debug('new prog tag: {}'.format(new_prog_tag), extra={
                             'iface': self.iface})
-
-                if section == self.xdp.get('section', 'xdp'):
-                    break
-                prog = libbpf.bpf_object__next_program(obj, prog)
-
-            if not prog:
-                logger.warning('XDP section {} on {} not found'.format(
-                    self.xdp.get('section'), self.iface))
-                return
-
-            # get prog fd
-            new_prog_fd = libbpf.bpf_program__fd(prog)
-            if not new_prog_fd:
-                logger.warning('XDP failed to get prog fd on {}'.format(
-                    self.iface))
-                return
         else:
             assert False, "unhandled XDP settings"
 
         # get new prog tag
-        if new_prog_fd != -1:
+        if new_prog_fd != -1 and new_prog_tag == None:
             info = struct_bpf_prog_info()
             sz = ctypes.c_uint(ctypes.sizeof(info))
             rc = libbpf.bpf_obj_get_info_by_fd(new_prog_fd, ctypes.byref(info), ctypes.byref(sz))
@@ -140,27 +121,26 @@ class XDP():
         # set new XDP prog if tag or attach mode has changed
         if current_prog_tag != new_prog_tag or not current_attached in new_attached:
             if do_apply:
+                attach_ok = False
                 try:
                     ipr.link('set', index=self.idx, xdp_fd=new_prog_fd, xdp_flags=new_flags)
+                    attach_ok = True
                 except Exception as err:
                     if not isinstance(err, netlinkerror_classes):
                         raise
 
-                    if new_prog_fd == -1:
+                    # try again: detaching XDP first
+                    try:
+                        ipr.link('set', index=self.idx, xdp_fd=-1)
+
+                        ipr.link('set', index=self.idx, xdp_fd=new_prog_fd, xdp_flags=new_flags)
+                        attach_ok = True
+                    except Exception as err:
+                        if not isinstance(err, netlinkerror_classes):
+                            raise
+
                         logger.warning('attaching XDP program on {} failed: {}'.format(
                             self.iface, err.args[1]))
-                    else:
-                        # try again: detaching XDP first
-                        try:
-                            ipr.link('set', index=self.idx, xdp_fd=-1)
-
-                            ipr.link('set', index=self.idx, xdp_fd=new_prog_fd, xdp_flags=new_flags)
-                        except Exception as err:
-                            if not isinstance(err, netlinkerror_classes):
-                                raise
-
-                            logger.warning('attaching XDP program on {} failed: {}'.format(
-                                self.iface, err.args[1]))
 
             if new_prog_fd == -1:
                 logger.info('detach', extra={
@@ -179,6 +159,7 @@ try:
     libbpf.bpf_object__next_program
     libbpf.bpf_object__load
     libbpf.bpf_object__open_file
+    libbpf.bpf_object__pin_maps
     libbpf.bpf_prog_get_fd_by_id
     libbpf.bpf_program__fd
     libbpf.bpf_program__section_name
